
var     
    y               ${y}$                   (long_name='Output')
    y_nat           ${y^{nat}}$             (long_name='Natural Output')
    y_gap           ${\tilde y}$            (long_name='Output Gap')
    pi              ${\pi}$                 (long_name='Inflation')
    i               ${i}$                   (long_name='Nominal Interrst Rate')
    y_bar           ${\bar{y}}$             (long_name='Trend component of Output')
    pi_bar          ${\bar{\pi}}$           (long_name='Trend component of Inflation')
    i_bar           ${\bar i}$              (long_name='Trend component of Nominal Interest Rate')
    v               ${v}$                   (long_name='Household Evolution of Marginal Value of Wealth')
    v_tilda         ${\tilde{v}}$           (long_name='Firm Evolution of Marginal Value of Wealth')
    a               ${a}$                   (long_name='Technology Shock Process')
    z               ${\zeta}$               (long_name='Pref Shock Process')
    chi             ${\chi}$                (long_name='Cost Push or Supply Shock Process')
    mu              ${\mu}$                 (long_name='Monetary Policy Shock Process') 
    n               ${n}$                   (long_name='Hours Worked')
    dy 
    pinfobs 
    robs
    labobs
    r_nat
;


varexo  
    eps_a           ${\varepsilon_a}$       (long_name='technology shock')
    eps_mu          ${\varepsilon_\mu}$     (long_name='monetary policy shock')
    eps_chi         ${\varepsilon_\chi}$    (long_name='Cost Push shock')
    eps_z           ${\varepsilon_\zeta}$   (long_name='Pref shock')
;

parameters 
    kappa           ${\kappa}$              (long_name='Slope of PC')
    rho             ${\rho}$                (long_name='Dampening or Myopic Parameter')
    dlta            ${\delta}$              (long_name='Gain parameter of Households')
    dlta_tilda      ${\tilde \delta}$       (long_name='Gain parameter of Firms')
    siggma          ${\sigma}$              (long_name='Relative Risk Aversion') % 1/sigma is elasticity of intertemporal substitution
    rho_a           ${\rho_a}$              (long_name='Autocorrelation Technology Shock')
    rho_mu          ${\rho_mu}$             (long_name='Autocorrelation Monetary Shock')
    rho_chi         ${\rho_\chi}$           (long_name='Autocorrelation Technology Shock')
    rho_i           ${\rho_{i}}$            (long_name='Interest rate smoothing parameter')
    rho_z           ${\rho_\zeta}$          (long_name='Autocorrelation Preferance Shock')
    phi_pi          ${\phi_{\pi}}$          (long_name='Inflation Feedback Taylor Rule')
    phi_y           ${\phi_{y}}$            (long_name='Output Feedback Taylor Rule')
    betta           ${\beta}$               (long_name='Discount Factor')
    phii            ${\phi}$                (long_name='Calvo Probability of not changing price')
    eta             ${\eta}$                (long_name='Inverse Frisch Elasticity of Labor Supply')
    phi_pi_bar      ${\bar {\phi_\pi}}$     (long_name='Trend Inflation Feedback Taylor Rule')
    phi_y_bar       ${\bar {\phi_y}}$       (long_name='Trend Output Feedback Taylor Rule')
    ctrend 
    constepinf 
    conster
    constelab
;

%----------------------------------------------------------------
% Parametrization
%----------------------------------------------------------------

kappa       = 0.11; %(((1-phii)*(1-phii*betta))/phii)*(siggma+eta); %0.11 using calibration of gabaix
rho         = 0.80;
dlta        = 0.1;
dlta_tilda  = 0.17;
siggma      = 5; // 0.20
rho_a       = 0.75;
rho_mu      = 0.75;  
rho_chi     = 0.75;
rho_z       = 0.75;
phi_pi      = 1.5;
phi_pi_bar  = 1.8;
phi_y       = 0.125;
phi_y_bar   = 0.1;
rho_i       = 0.75;
betta       = 0.996;
phii        = 0.875;
eta         = 1.0;   
ctrend      = 0.4; 
constepinf  = 0.625; 
conster     = 1.0148;
constelab   = 1.2918;

options_.TeX=1;

%----------------------------------------------------------------
% Linear Model
%----------------------------------------------------------------

model (linear);

y_gap-z-y_bar =rho*(y_gap(+1)-z(+1)-y_bar(+1))-(1/siggma)*(i-i_bar-r_nat-rho*(pi(+1)-pi_bar(+1)));
pi-pi_bar=betta*rho*(pi(+1)-pi_bar(+1))+kappa*(y_gap-y_bar)-chi;
i-i_bar=rho_i*(i(-1)-i_bar(-1))+(1-rho_i)*(phi_pi*(pi-pi_bar)+phi_y*(y_gap-y_bar))+mu;
i_bar=phi_pi_bar*pi_bar+phi_y_bar*y_bar;
y_gap=y-y_nat;
y=a+n;

%r_nat=-gama*((1+eta)/(gama+eta))*(1-rho_a)*a;
%r_nat=(1+eta)/(siggma*(gama+eta))*(a(+1)-a)+z;
r_nat=rho_a*r_nat(-1)+siggma*(rho_a-1)*((1+eta)/(siggma+eta))*eps_a; //from Sims 

y_bar=rho*y_bar-siggma*(i_bar-rho*pi_bar)+(1-rho)*v;
v=dlta*(y_gap(-1)-z(-1)+siggma*pi(-1))+(1-dlta)*v(-1);

pi_bar=betta*rho*pi_bar+kappa*y_bar+(1-phii)*betta*(1-rho)*v_tilda;
v_tilda=(dlta_tilda*pi(-1))/(1-phii)+(1-dlta_tilda)*v_tilda(-1);

%y_nat=((1-alppha)*(1+eta))/(1+ eta+(1-alppha)*(gama-1))*a;
y_nat=((1+eta)/(siggma+eta))*a;

a=rho_a*a(-1)+eps_a;
mu=rho_mu*mu(-1)+eps_mu;
chi=rho_chi*chi(-1)+eps_chi;
z=rho_z*z(-1)+eps_z;

dy         = (y_gap - y_gap(-1)) + ctrend;
pinfobs    = pi + constepinf;
robs       = i + conster;
labobs     = n + constelab; 

end;


shocks;
    var eps_a;          stderr 0.02;
    var eps_mu;         stderr 0.02;
    var eps_chi;        stderr 0.02;
    var eps_z;          stderr 0.02;
end;


resid(1);
steady;
check;

write_latex_original_model;
write_latex_static_model;
write_latex_dynamic_model(write_equation_tags);
write_latex_parameter_table;
write_latex_definitions;


%----------------------------------------------------------------
% Bayesian Estimation
%---------------------------------------------------------------- 

estimated_params;

        stderr eps_a,       INV_GAMMA_PDF,  0.02, 2.00; 
        stderr eps_z,       INV_GAMMA_PDF,  0.02, 2.00; 
        stderr eps_mu,      INV_GAMMA_PDF,  0.02, 2.00;
        stderr eps_chi,     INV_GAMMA_PDF,  0.02, 2.00;
        rho_a,              BETA_PDF,       0.75, 0.10;
        rho_mu,             BETA_PDF,       0.75, 0.10;
        rho_chi,            BETA_PDF,       0.75, 0.10;
        rho_z,              BETA_PDF,       0.75, 0.10;
        %rho_i,              BETA_PDF,       0.75, 0.10; 
        phi_pi,             NORMAL_PDF,     1.50, 0.15; 
        phi_y,              NORMAL_PDF,     0.50, 0.05;
        phi_pi_bar,         NORMAL_PDF,     1.50, 0.50; 
        phi_y_bar,          NORMAL_PDF,     0.10, 0.05;
    %   rho,                BETA_PDF,       0.50, 0.10;    
    %   dlta,               BETA_PDF,       0.20, 0.10; 
    %   dlta_tilda,         BETA_PDF,       0.20, 0.10; 
    %   siggma,             GAMMA_PDF,      2.00, 0.50;                      
    %   gama,               NORMAL_PDF,     1.50, 0.37;
    %   eta,               BETA_PDF,       0.50, 0.10;     
    %   betta,              BETA_PDF,       0.25, 0.10;
    %   phii,              BETA_PDF,       0.66, 0.05;
        constepinf,         GAMMA_PDF,      0.625,0.10; 
        ctrend,             NORMAL_PDF,     0.40, 0.10; 
        conster,            NORMAL_PDF,     1.5,  0.1; 
        constelab,          NORMAL_PDF,     0.0,  2.0;
        rho,                UNIFORM_PDF,,,       0, 1;    
        dlta,               UNIFORM_PDF,,,       0, 1; 
        dlta_tilda,         UNIFORM_PDF,,,       0, 1; 
        
end;

steady_state_model;
dy = ctrend;
pinfobs = constepinf;
robs  = conster;
labobs= constelab;
end;

write_latex_prior_table;

varobs dy pinfobs robs labobs;
identification(advanced=1);

options_.plot_priors=0;
%options_.dsge_varlag = 3;

estimation(
    datafile='usdata',
    mode_compute=0,
    mode_file=NKmodel_mode,
    presample=4,
    lik_init=2,
    prefilter=0,
    mh_replic=0,
    mh_nblocks=2,
    mh_jscale=0.20,
    mh_drop=0.5, 
    bayesian_irf,
    filtered_vars,
    forecast=12,
    mode_check,
    mh_tune_jscale
    ) 
dy pinfobs robs labobs;

%generate_trace_plots(1);
%stoch_simul(order=1, irf=40,ar=10 ) dy  pinfobs robs labobs y_gap pi y n i;

bvar_forecast(forecast = 12) 8;

model_diagnostics;
collect_latex_files;









    